<?php
/**
 * Feed Item List Page
 *
 * Lists items in a given feed (all, unread, or bookmarked)
 *
 * @author Daniel J. Summers <daniel@bitbadger.solutions>
 * @license MIT
 */

declare(strict_types=1);

use FeedReaderCentral\{Feed, ItemList};

include '../../start.php';

FeedReaderCentral\Security::verifyUser();

$id   = key_exists('id', $_GET) ? (int)$_GET['id'] : -1;
$feed = Feed::retrieveById($id)->getOrCall(not_found(...));

$list = match (true) {
    key_exists('unread',     $_GET) => ItemList::unreadForFeed($feed->id),
    key_exists('bookmarked', $_GET) => ItemList::bookmarkedForFeed($feed->id),
    default                         => ItemList::allForFeed($feed->id)
};

page_head(($list->itemType === '' ? '' : "$list->itemType Items | ") . strip_tags($feed->title));
if ($list->itemType === '') {
    echo '<h1>' . htmlentities($feed->title) . '</h1>';
} else {
    echo '<h1 class=item_heading>' . htmlentities($feed->title) . '</h1>';
    echo "<div class=item_published>$list->itemType Items</div>";
}
$list->render();
page_foot();
