<?php
/**
 * Home Page
 *
 * Displays a list of unread or bookmarked items for the current user
 *
 * @author Daniel J. Summers <daniel@bitbadger.solutions>
 * @license MIT
 */

declare(strict_types=1);

use FeedReaderCentral\{Feed, ItemList};

include '../start.php';

FeedReaderCentral\Security::verifyUser();

if (key_exists('refresh', $_GET)) {
    $refreshResult = Feed::refreshAll();
    if ($refreshResult->isOK()) {
        add_info('All feeds refreshed successfully');
    } else {
        add_error(nl2br($refreshResult->getError()));
    }
}

$list = match (true) {
    key_exists('bookmarked', $_GET) => ItemList::allBookmarked(),
    default                         => ItemList::allUnread(),
};
$title = "Your $list->itemType Items";

page_head($title);
echo "<h1>$title";
if ($list->itemType == 'Unread') {
    echo ' &nbsp; ' . hx_get('/?refresh', '(Refresh All Feeds)', 'class=refresh hx-indicator="closest h1"')
        . '<span class=loading>Refreshing&hellip;</span>';
}
echo '</h1>';
$list->render();
page_foot();
