<?php
/**
 * Item View Page
 *
 * Retrieves and displays an item from a feed belonging to the current user
 *
 * @author Daniel J. Summers <daniel@bitbadger.solutions>
 * @license MIT
 */

declare(strict_types=1);

use BitBadger\PDODocument\{Delete, DocumentException, Patch};
use FeedReaderCentral\{ItemWithFeed, Table};

include '../start.php';

FeedReaderCentral\Security::verifyUser();

$id = match (true) {
    key_exists('id', $_POST) => (int)$_POST['id'],
    key_exists('id', $_GET)  => (int)$_GET['id'],
    default                  => -1,
};
$from = match ($_SERVER['REQUEST_METHOD']) {
    'POST'  => $_POST['from'],
    default => $_GET['from'] ?? '/',
};

switch ($_SERVER['REQUEST_METHOD']) {
    case 'POST':
        try {
            // "Keep as New" button sends a POST request to reset the is_read flag before going back to the item list
            if (ItemWithFeed::existsById($id)) {
                Patch::byId(Table::Item, $id, ['is_read' => 0]);
            }
            frc_redirect($from);
        } catch (DocumentException $ex) {
            add_error("$ex");
        }
        break;

    case 'DELETE':
        try {
            if (ItemWithFeed::existsById($id)) Delete::byId(Table::Item, $id);
        } catch (DocumentException $ex) {
            add_error("$ex");
        }
        frc_redirect($from);
}

$item = ItemWithFeed::retrieveById($id)->getOrCall(not_found(...));
try {
    Patch::byId(Table::Item, $id, ['is_read' => 1]);
} catch (DocumentException $ex) {
    add_error("$ex");
}

$published = date_time($item->published_on);
$updated   = isset($item->updated_on) ? date_time($item->updated_on) : null;

page_head(htmlentities("$item->title | {$item->feed->title}")); ?>
<h1 class=item_heading>
    <span class=bookmark hx-get="/bookmark?id=<?=$_GET['id']?>" hx-trigger=load hx-target=this hx-swap=outerHTML
          hx-push-url=false></span>
    <a href="<?=$item->item_link?>" target=_blank rel=noopener><?=strip_tags($item->title)?></a><br>
</h1>
<div class=item_published>
    From <strong><?=htmlentities($item->feed->title)?></strong><br>
    Published <?=date_time($item->published_on)?><?=$updated && $updated != $published ? " (Updated $updated)" : ''?>
</div>
<article>
    <div class=item_content><?=str_replace('<a ', '<a target=_blank rel=noopener ', $item->content)?></div>
    <form class=action_buttons action=/item method=POST hx-post=/item>
        <input type=hidden name=id value=<?=$_GET['id']?>>
        <input type=hidden name=from value="<?=$from?>">
        <?=hx_get($from, 'Done')?>
        <button type=submit>Keep as New</button>
        <button type=button hx-delete=/item>Delete</button>
    </form>
</article><?php
page_foot();
