<?php declare(strict_types=1);

/**
 * USER CONFIGURATION ITEMS
 *
 * Editing the values here customizes the behavior of Feed Reader Central
 *
 * On initial installation, rename this file to user-config.php and configure it as desired
 */

use FeedReaderCentral\{Feed, Security};

/**
 * Which security model should the application use? Options are:
 * - Security::SingleUserMode (no e-mail required, does not require a password)
 * - Security::SingleUserPasswordMode (no e-mail required, does require a password)
 * - Security::MultiUserMode (e-mail and password required for all users)
 */
const SECURITY_MODEL = 'ConfigureMe';

/** The name of the database file where users and feeds should be kept */
const DATABASE_NAME = 'frc.db';

/**
 * The format for date/time outputs; see https://www.php.net/manual/en/datetime.format.php for acceptable values
 *
 * The default, 'F j, Y \a\t g:ia', equates to "August 17, 2023 at 4:45pm"
 */
const DATE_TIME_FORMAT = 'F j, Y \a\t g:ia';

/**
 * How should item purging be done? (Purging never applies to bookmarked items.) Options are:
 * - Feed::PurgeNone - Do not purge items
 * - Feed::PurgeRead - Purge all read items whenever purging is run (will not purge unread items)
 * - Feed::PurgeByDays - Purge read and unread items older than a number of days (PURGE_NUMBER below)
 * - Feed::PurgeByCount - Purge read and unread items beyond the number to keep (PURGE_NUMBER below)
 */
const PURGE_TYPE = Feed::PurgeByDays;

/**
 * For purge-by-days, how many days of items should be kept; for purge-by-count, how many items should be kept
 */
const PURGE_NUMBER = 30;
